==> 1.0.0.tar.gz: ios/Classes/SwiftFlutterSecureKeyboardPlugin.swift <==
import Flutter
import UIKit

public class SwiftFlutterSecureKeyboardPlugin: NSObject, FlutterPlugin {
    private var methodChannel: FlutterMethodChannel?
    
    private var isSecureModeOn: Bool = false
    private var notificationObserver: NSObjectProtocol? = nil
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let instance = SwiftFlutterSecureKeyboardPlugin()
        instance.setupChannels(registrar.messenger())
        registrar.addApplicationDelegate(instance)
    }
    
    private func setupChannels(_ messenger: FlutterBinaryMessenger) {
        methodChannel = FlutterMethodChannel(name: "flutter_secure_keyboard", binaryMessenger: messenger)
        methodChannel?.setMethodCallHandler(onMethodCall)
    }

    private func onMethodCall(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
            case "secureModeOn":
                if (notificationObserver == nil) {
                    notificationObserver = NotificationCenter.default.addObserver(
                        forName: UIApplication.userDidTakeScreenshotNotification,
                        object: nil,
                        queue: nil,
                        using: applicationUserDidTakeScreenshot
                    )
                }
                isSecureModeOn = true
                break;
            case "secureModeOff":
                if (notificationObserver != nil) {
                    NotificationCenter.default.removeObserver(notificationObserver!)
                    notificationObserver = nil
                }
                isSecureModeOn = false
                break;
            default:
                result(FlutterMethodNotImplemented)
        }
    }
    
    public func applicationWillResignActive(_ application: UIApplication) {
        if (isSecureModeOn) {
            UIApplication.shared.delegate?.window??.isHidden = true
        }
    }
    
    public func applicationDidBecomeActive(_ application: UIApplication) {
        if (isSecureModeOn) {
            UIApplication.shared.delegate?.window??.isHidden = false
        }
    }
    
    public func applicationUserDidTakeScreenshot(_ notification: Notification) {
        let localeID = Locale.preferredLanguages.first
        let deviceLocale = (Locale(identifier: localeID ?? "en").languageCode) ?? "en"
        
        let alert: UIAlertController
        let alertAction: UIAlertAction
        if (deviceLocale == "ko") {
            alert = UIAlertController(
                title: "보안 경고",
                message: "보안 문자를 입력하는 동안 화면 캡처가 탐지되었습니다.",
                preferredStyle: UIAlertController.Style.alert
            )
            alertAction = UIAlertAction(title: "확인", style: .default, handler: nil)
        } else {
            alert = UIAlertController(
                title: "Security Warning",
                message: "Screen Capture was detected while entering secure text.",
                preferredStyle: UIAlertController.Style.alert
            )
            alertAction = UIAlertAction(title: "OK", style: .default, handler: nil)
        }
        alert.addAction(alertAction)
        
        UIApplication.shared.delegate?.window??.rootViewController!.present(alert, animated: true, completion: nil)
    }
}

==> 1.0.2.tar.gz: ios/Classes/SwiftFlutterSecureKeyboardPlugin.swift <==
import Flutter
import UIKit

public class SwiftFlutterSecureKeyboardPlugin: NSObject, FlutterPlugin {
    private var methodChannel: FlutterMethodChannel?
    
    private var isSecureModeOn: Bool = false
    private var screenCaptureDetectedAlertTitle: String?
    private var screenCaptureDetectedAlertMessage: String?
    private var screenCaptureDetectedAlertActionTitle: String?
    private var notificationObserver: NSObjectProtocol? = nil
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let instance = SwiftFlutterSecureKeyboardPlugin()
        instance.setupChannels(registrar.messenger())
        registrar.addApplicationDelegate(instance)
    }
    
    private func setupChannels(_ messenger: FlutterBinaryMessenger) {
        methodChannel = FlutterMethodChannel(name: "flutter_secure_keyboard", binaryMessenger: messenger)
        methodChannel?.setMethodCallHandler(onMethodCall)
    }

    private func onMethodCall(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
            case "secureModeOn":
                guard let args = call.arguments as? Dictionary<String, Any> else {
                    result(FlutterError(code: call.method, message: "Missing argument", details: nil))
                    return
                }
                
                if (notificationObserver == nil) {
                    notificationObserver = NotificationCenter.default.addObserver(
                        forName: UIApplication.userDidTakeScreenshotNotification,
                        object: nil,
                        queue: nil,
                        using: applicationUserDidTakeScreenshot
                    )
                }
                isSecureModeOn = true
                screenCaptureDetectedAlertTitle = args["screenCaptureDetectedAlertTitle"] as? String
                screenCaptureDetectedAlertMessage = args["screenCaptureDetectedAlertMessage"] as? String
                screenCaptureDetectedAlertActionTitle = args["screenCaptureDetectedAlertActionTitle"] as? String
                break
            case "secureModeOff":
                if (notificationObserver != nil) {
                    NotificationCenter.default.removeObserver(notificationObserver!)
                    notificationObserver = nil
                }
                isSecureModeOn = false
                screenCaptureDetectedAlertTitle = nil
                screenCaptureDetectedAlertMessage = nil
                break
            default:
                result(FlutterMethodNotImplemented)
        }
    }
    
    public func applicationWillResignActive(_ application: UIApplication) {
        if (isSecureModeOn) {
            UIApplication.shared.delegate?.window??.isHidden = true
        }
    }
    
    public func applicationDidBecomeActive(_ application: UIApplication) {
        if (isSecureModeOn) {
            UIApplication.shared.delegate?.window??.isHidden = false
        }
    }
    
    public func applicationUserDidTakeScreenshot(_ notification: Notification) {
        let alertTitle: String
        let alertMessage: String
        let alertActionTitle: String
        
        let localeID = Locale.preferredLanguages.first
        let deviceLocale = (Locale(identifier: localeID ?? "en").languageCode) ?? "en"
        
        if (deviceLocale == "ko") {
            alertTitle = "보안 경고"
            alertMessage = "보안 문자를 입력하는 동안 화면 캡처가 탐지되었습니다."
            alertActionTitle = "확인"
        } else {
            alertTitle = "Security Warning"
            alertMessage = "Screen Capture was detected while typing secure text."
            alertActionTitle = "OK"
        }
        
        let alert = UIAlertController(
            title: screenCaptureDetectedAlertTitle ?? alertTitle,
            message: screenCaptureDetectedAlertMessage ?? alertMessage,
            preferredStyle: .alert
        )
        let alertAction = UIAlertAction(
            title: screenCaptureDetectedAlertActionTitle ?? alertActionTitle,
            style: .default
        )
        alert.addAction(alertAction)
        
        UIApplication.shared.delegate?.window??.rootViewController!.present(alert, animated: true, completion: nil)
    }
}
